# amanobot - Python framework for Telegram Bot API based on Telepot

**[Bot API 4.1](https://core.telegram.org/bots/api)**-compliant!

### [Introduction »](http://amanobot.readthedocs.io/en/latest/)
### [Reference »](http://amanobot.readthedocs.io/en/latest/reference.html)
### [Examples »](https://github.com/AmanoTeam/amanobot/tree/master/examples)
### [Changelog »](https://github.com/AmanoTeam/amanobot/blob/master/CHANGELOG.md)
